@@ -10,7 +10,10 @@ from jbutils.utils.utils import (
     find,
     get_keys,
     get_nested,
+    joiner,
     parse_csv_line,
+    p_exists,
+    p_join,
     pretty_print,
     print_stack_trace,
     read_file,
@@ -42,7 +45,10 @@ __all__ = [
     "get_nested",
     "jbcfg",
     "jbutils",
+    "joiner",
     "parse_csv_line",
+    "p_exists",
+    "p_join",
     "pretty_print",
     "print_stack_trace",
     "read_file",
