@@ -16,7 +16,7 @@ from jbutils import jbutils
 TOOL_DIR = os.path.dirname(__file__)
 JBUTILS_DIR = os.path.dirname(TOOL_DIR)
 PROJ_DIR = os.path.dirname(JBUTILS_DIR)
-UTILS_PATH = os.path.join(PROJ_DIR, "utils", "utils.py")
+UTILS_PATH = os.path.join(JBUTILS_DIR, "utils", "utils.py")
 
 _parser = argparse.ArgumentParser(description=__doc__)
 cmn_handler = jbutils.add_common_args(_parser, UTILS_PATH, proj_dir=PROJ_DIR)
