@@ -13,11 +13,19 @@ import sys
 import traceback
 import fnmatch
 
+# _vi = sys.version_info
+# if _vi.major >= 3 and _vi.minor >= 11:
+try:
+    import tomllib
+except:
+    import tomli as tomllib
+
 from pathlib import Path
 from platform import platform
 
 from collections.abc import Callable
 from dataclasses import dataclass
+from time import time
 from typing import Any, Optional
 
 import jsonlines
@@ -31,7 +39,15 @@ from ruamel.yaml.tokens import CommentToken
 from ruamel.yaml.scalarstring import LiteralScalarString, ScalarString
 from typing_extensions import TypeGuard
 
-from jbutils.types import CommandArg, T, Patterns, DataPath, DataPathList, SubReturn
+from jbutils.types import (
+    CommandArg,
+    T,
+    Patterns,
+    DataPath,
+    DataPathList,
+    SubReturn,
+    StrVarArgsFn,
+)
 
 yaml = YAML()
 yaml.indent = 2
@@ -125,6 +141,9 @@ def read_file(
         return default_val
 
     ext = get_ext(path).lower()
+    if ext == ".toml":
+        mode = "rb"
+        encoding = None
 
     with open(path, mode, encoding=encoding, *args, **kwargs) as fs:
         match ext:
@@ -134,6 +153,8 @@ def read_file(
                 return json.load(fs)
             case ".jsonl":
                 return [item for item in jsonlines.Reader(fs).iter()]
+            case ".toml":
+                return tomllib.load(fs)
             case ".csv":
                 data = list(csv.reader(fs))
                 if as_dicts:
@@ -1030,7 +1051,7 @@ def add_common_args(
         args = parser.parse_args()
         arg_props = vars(args)
         if arg_props.get(code.arg_name):
-            cmdx(f"code {proj_path}")
+            cmdx(f'code "{proj_path}"')
             sys.exit(0)
         if arg_props.get(cd.arg_name):
             path = proj_dir
@@ -1089,3 +1110,25 @@ def extract_comment(data: CommentedMap | CommentedSeq) -> str:
     if not comment:
         return ""
     return comment[0].value
+
+
+def joiner(path: str = "") -> StrVarArgsFn:
+    return lambda *x: os.path.join(path, *x)
+
+
+def p_join(path: str, *subpaths: str) -> str:
+    f"""{os.path.join.__doc__}"""
+    return os.path.join(path, *subpaths)
+
+
+def p_exists(path: str) -> bool:
+    return os.path.exists(path)
+
+
+def profile(func: Callable, *args, **kwargs) -> float:
+    start = time()
+    func(*args, **kwargs)
+    return round((time() - start) * 1000, 3)
+
+
+p_exists.__doc__ = os.path.exists.__doc__
